/**gui.h is part of JamMo.
License: GPLv2, read more from COPYING

Graphical user interface must implement all these functions.
*/

#ifndef _GUI_H_
#define _GUI_H_

#define WIDTH_OF_WINDOW 800
#define HEIGHT_OF_WINDOW 480
//These are different state of Game.
enum {
  SCREEN_WELCOME = 0,
  SCREEN_PASSWORD_TYPING,
  SCREEN_GAME_SELECTION, //This is main-menu
  SCREEN_THEME_SELECTION,
  SCREEN_COMPOSING,
  SCREEN_SONG_SELECTION,
  SCREEN_SONG_RECORDING,
  SCREEN_PLAY_RECORDED,
  SCREEN_MIDI_EDITOR,
  SCREEN_SEQUENCER,
  SCREEN_STARTMENU,
  SCREEN_GAMESMENU,
  SCREEN_COMMUNITYMENU,
  NUMBER_OF_SCREENS, //Keep this entry last.
};



#endif /*  _GUI_H_  */
